@@ -1,8 +1,5 @@
 import click
 import yaml
-import boto3
-import base64
-from botocore.exceptions import ClientError
 from aws_secrets.miscellaneous.kms import encrypt
 from aws_secrets.miscellaneous import session
 
@@ -10,19 +7,20 @@ from aws_secrets.miscellaneous import session
 @click.command(name='set-parameter')
 @click.option('-e', '--env-file', type=click.Path(), required=True)
 @click.option('-n', '--name', prompt=True, required=True)
+@click.option('-d', '--description', help='SSM Parameter Description', required=False)
 @click.option('-t', '--type',
               required=True, type=click.Choice(['String', 'SecureString'], case_sensitive=True),
               default='SecureString')
 @click.option('-k', '--kms')
 @click.option('--profile')
 @click.option('--region')
-def set_parameter(env_file, name, type, kms, profile, region):
+def set_parameter(env_file, name, description, type, kms, profile, region):
     session.aws_profile = profile
     session.aws_region = region
     with open(env_file, 'r') as env:
         yaml_data = yaml.safe_load(env.read())
 
-    if not 'parameters' in yaml_data:
+    if 'parameters' not in yaml_data:
         yaml_data['parameters'] = []
 
     parameter = next(
@@ -35,6 +33,9 @@ def set_parameter(env_file, name, type, kms, profile, region):
         }
         yaml_data['parameters'].append(parameter)
 
+    if description:
+        parameter['description'] = description
+
     if kms:
         parameter['kms'] = kms
 
@@ -48,7 +49,7 @@ def set_parameter(env_file, name, type, kms, profile, region):
         contents.append(line)
 
     value = '\n'.join(contents)
-    
+
     if parameter['type'] == 'SecureString':
         kms_arn = str(yaml_data['kms']['arn'])
         print('Encrypting the value')
@@ -59,4 +60,4 @@ def set_parameter(env_file, name, type, kms, profile, region):
         parameter['value'] = value
 
     with open(env_file, 'w') as outfile:
-        yaml.safe_dump(yaml_data, outfile)
\ No newline at end of file
+        yaml.safe_dump(yaml_data, outfile)
