@@ -1,26 +1,24 @@
 import click
 import yaml
-import boto3
-import base64
-from botocore.exceptions import ClientError
-from aws_secrets.miscellaneous import kms
+from aws_secrets.miscellaneous.kms import encrypt
 from aws_secrets.miscellaneous import session
 
 
 @click.command(name='set-secret')
 @click.option('-e', '--env-file', type=click.Path(), required=True)
 @click.option('-n', '--name', required=True)
+@click.option('-d', '--description', help='Secret Description', required=False)
 @click.option('-k', '--kms')
 @click.option('--profile')
 @click.option('--region')
-def set_secret(env_file, name, type, kms, profile, region):
+def set_secret(env_file, name, description, kms, profile, region):
     session.aws_profile = profile
     session.aws_region = region
-    
+
     with open(env_file, 'r') as env:
         yaml_data = yaml.safe_load(env.read())
 
-    if not 'secrets' in yaml_data:
+    if 'secrets' not in yaml_data:
         yaml_data['secrets'] = []
 
     secret = next(
@@ -32,6 +30,9 @@ def set_secret(env_file, name, type, kms, profile, region):
         }
         yaml_data['secrets'].append(secret)
 
+    if description:
+        secret['description'] = description
+
     if kms:
         secret['kms'] = kms
 
@@ -48,7 +49,7 @@ def set_secret(env_file, name, type, kms, profile, region):
 
     value = '\n'.join(contents)
 
-    encrypted_value = kms.encrypt(session.session(), value, kms_arn)
+    encrypted_value = encrypt(session.session(), value, kms_arn)
     secret['value'] = encrypted_value.decode('utf-8')
 
     with open(env_file, 'w') as outfile:
